@@ -834,7 +834,7 @@ pci_comp_err_info_print(sal_log_pci_comp_err_info_t *pcei)
 		iprintf("Invalid PCI Component Error Record format: length = %d, "
 		       " Size PCI Data = %ld, Num Mem-Map/IO-Map Regs = %d/%d\n",
 		       pcei->header.len, n_pci_data, n_mem_regs, n_io_regs);
-		return;
+		goto out;
 	}
 
 	if (n_mem_regs) {
@@ -857,9 +857,11 @@ pci_comp_err_info_print(sal_log_pci_comp_err_info_t *pcei)
 	}
 	if (pcei->valid.oem_data)
 		platform_pci_comp_err_print(&pcei->header, p_oem_data);
+out:
+	--indent;
 }
 
-/* Format and log the platform specifie error record section data */
+/* Format and log the platform specific error record section data */
 static void
 plat_specific_err_info_print (sal_log_plat_specific_err_info_t *psei)
 {
